window.Gleam.initSearch([{"doc":"glubs","title":"glubs","content":"# glubs - Subtitle parser\n\n[![Package Version](https://img.shields.io/hexpm/v/glubs)](https://hex.pm/packages/glubs)\n[![Hex Docs](https://img.shields.io/badge/hex-docs-ffaff3)](https://hexdocs.pm/glubs/)\n\nglubs is a WebVTT and SRT parser and serializer written in Gleam.\nIt also has a tokenizer for formatted WebVTT payloads.\n\n## Installation\n\nIf available on Hex this package can be added to your Gleam project:\n\n```sh\ngleam add glubs\n```\n\nand its documentation can be found at &lt;https://hexdocs.pm/glubs&gt;.\n\n## Features\n\n* [x] Parses WebVTT files into a structured format\n* [x] Handles both comments and cues with start and end times\n* [x] Tokenizes WebVTT cue payload into individual tokens\n* [x] Converts a WebVTT type back to a string\n* [x] Parse SRT\n* [x] Convert SRT to string\n* [x] Support WebVTT STYLE-Tags (https://developer.mozilla.org/en-US/docs/Web/API/WebVTT_API#styling_webvtt_cues)\n* [x] Support WebVTT cue settings (https://developer.mozilla.org/en-US/docs/Web/API/WebVTT_API#cue_settings)\n* [x] Support WebVTT header metadata\n* [x] Support HLS X-TIMESTAMP-MAP\n\n## Example\n\n```gleam\nimport glubs/webvtt.{Cue, EndTag, Note, StartTag, Text, WebVTT}\nimport gleam/option.{None, Some}\nimport simplifile\n\npub fn main() {\n  // WebVTT parser\n  let assert Ok(content) = simplifile.read(&quot;test/fixtures/comments.vtt&quot;)\n  let assert Ok(result) = webvtt.parse(content)\n\n  let assert WebVTT(\n    comment: Some(&quot;- Translation of that film I like&quot;),\n    metadata: [],\n    items: [\n      Note(\n        &quot;This translation was done by Kyle so that\\nsome friends can watch it with their parents.&quot;,\n      ),\n      Cue(\n        id: Some(&quot;1&quot;),\n        start_time: 135_000,\n        end_time: 140_000,\n        payload: &quot;- Ta en kopp varmt te.\\n- Det är inte varmt.&quot;,\n        settings: [],\n      ),\n      Cue(\n        id: Some(&quot;2&quot;),\n        start_time: 140_000,\n        end_time: 145_000,\n        payload: &quot;- Har en kopp te.\\n- Det smakar som te.&quot;,\n        settings: [],\n      ),\n      Note(&quot;This last line may not translate well.&quot;),\n      Cue(\n        id: Some(&quot;3&quot;),\n        start_time: 145_000,\n        end_time: 150_000,\n        payload: &quot;- Ta en kopp&quot;,\n        settings: [],\n      ),\n    ],\n  ) = result\n\n  // Cue payload tokenizer\n  let assert Ok(tokens) =\n    &quot;&lt;v Phil&gt;Hi!\\n&lt;v.loud.shout Rob&gt;Hello &lt;i&gt;mate!&lt;/i&gt;&lt;/v&gt;&quot;\n    |&gt; webvtt.tokenize()\n\n  let assert [\n    StartTag(&quot;v&quot;, classes: [], annotation: Some(&quot;Phil&quot;)),\n    Text(&quot;Hi!\\n&quot;),\n    StartTag(&quot;v&quot;, classes: [&quot;loud&quot;, &quot;shout&quot;], annotation: Some(&quot;Rob&quot;)),\n    Text(&quot;Hello &quot;),\n    StartTag(&quot;i&quot;, classes: [], annotation: None),\n    Text(&quot;mate!&quot;),\n    EndTag(&quot;i&quot;),\n    EndTag(&quot;v&quot;),\n  ] = tokens\n}\n```\n","url":"index.html"},{"doc":"glubs/srt","title":"Cue","content":"pub type Cue {\n  Cue(id: Int, start_time: Int, end_time: Int, payload: String)\n}\n Cue represents a single cue in a srt file.\nCue(id: Int, start_time: Int, end_time: Int, payload: String)\n\n\nSynonyms:\nglubs/srt.Cue\nglubs/srt Cue","url":"glubs/srt.html#Cue"},{"doc":"glubs/srt","title":"Srt","content":"pub type Srt {\n  Srt(cues: List(Cue))\n}\n\nSrt(cues: List(Cue))\n\n\nSynonyms:\nglubs/srt.Srt\nglubs/srt Srt","url":"glubs/srt.html#Srt"},{"doc":"glubs/srt","title":"parse","content":"pub fn parse(input: String) -&gt; Result(Srt, String)\n Parses a Srt string and returns a Result containing the parsed Srt structure or a parsing error.\nSynonyms:\nglubs/srt.parse\nglubs/srt parse","url":"glubs/srt.html#parse"},{"doc":"glubs/srt","title":"to_string","content":"pub fn to_string(srt: Srt) -&gt; String\n Converts a Srt type to a string.\nSynonyms:\nglubs/srt.to_string\nglubs/srt to_string","url":"glubs/srt.html#to_string"},{"doc":"glubs/srt","title":"glubs/srt","content":"","url":"glubs/srt.html"},{"doc":"glubs/webvtt","title":"Item","content":"pub type Item {\n  Note(String)\n  Style(String)\n  Cue(\n    id: Option(String),\n    start_time: Int,\n    end_time: Int,\n    payload: String,\n    settings: List(#(String, String)),\n  )\n}\n Item represents an individual item in a WebVTT file, which can be either a Note or a Cue.\nNote(String)\n\n\nStyle(String)\n\n\nCue(\n  id: Option(String),\n  start_time: Int,\n  end_time: Int,\n  payload: String,\n  settings: List(#(String, String)),\n)\n\n\nSynonyms:\nglubs/webvtt.Item\nglubs/webvtt Item","url":"glubs/webvtt.html#Item"},{"doc":"glubs/webvtt","title":"Token","content":"pub type Token {\n  StartTag(\n    tag: String,\n    classes: List(String),\n    annotation: Option(String),\n  )\n  Text(content: String)\n  Timestamp(ms: Int)\n  EndTag(tag: String)\n}\n Token represents individual tokens that can be generated during the tokenization of WebVTT cue payload.\nStartTag(\n  tag: String,\n  classes: List(String),\n  annotation: Option(String),\n)\n\n\nText(content: String)\n\n\nTimestamp(ms: Int)\n\n\nEndTag(tag: String)\n\n\nSynonyms:\nglubs/webvtt.Token\nglubs/webvtt Token","url":"glubs/webvtt.html#Token"},{"doc":"glubs/webvtt","title":"TokenizationError","content":"pub type TokenizationError {\n  InvalidStartToken\n  InvalidEndToken\n}\n TokenizationError represents errors that may occur during the tokenization process.\nInvalidStartToken\n\n\nInvalidEndToken\n\n\nSynonyms:\nglubs/webvtt.TokenizationError\nglubs/webvtt TokenizationError","url":"glubs/webvtt.html#TokenizationError"},{"doc":"glubs/webvtt","title":"WebVTT","content":"pub type WebVTT {\n  WebVTT(\n    metadata: List(#(String, String)),\n    comment: Option(String),\n    items: List(Item),\n  )\n}\n Represents a WebVTT file with an optional comment and a list of items.\nWebVTT(\n  metadata: List(#(String, String)),\n  comment: Option(String),\n  items: List(Item),\n)\n\n\nSynonyms:\nglubs/webvtt.WebVTT\nglubs/webvtt WebVTT","url":"glubs/webvtt.html#WebVTT"},{"doc":"glubs/webvtt","title":"parse","content":"pub fn parse(webvtt: String) -&gt; Result(WebVTT, String)\n Parses a WebVTT string and returns a Result containing the parsed WebVTT structure or a parsing error.\nSynonyms:\nglubs/webvtt.parse\nglubs/webvtt parse","url":"glubs/webvtt.html#parse"},{"doc":"glubs/webvtt","title":"to_string","content":"pub fn to_string(webvtt: WebVTT) -&gt; String\n Converts a WebVTT type to a string.\nSynonyms:\nglubs/webvtt.to_string\nglubs/webvtt to_string","url":"glubs/webvtt.html#to_string"},{"doc":"glubs/webvtt","title":"tokenize","content":"pub fn tokenize(\n  payload: String,\n) -&gt; Result(List(Token), TokenizationError)\n Tokenizes the given cue payload and returns a Result containing the list of generated tokens or a tokenization error.\nSynonyms:\nglubs/webvtt.tokenize\nglubs/webvtt tokenize","url":"glubs/webvtt.html#tokenize"},{"doc":"glubs/webvtt","title":"glubs/webvtt","content":"","url":"glubs/webvtt.html"}]);